#
# spec file for package python-drgn
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-drgn
Version:        0.0.31
Release:        1.1
Summary:        Scriptable debugger library
License:        LGPL-2.1-or-later
Group:          Development/Tools/Debuggers
URL:            https://github.com/osandov/drgn
Source:         drgn-%{version}.tar.xz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module readline}
BuildRequires:  %{python_module setuptools}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  check-devel
BuildRequires:  fdupes
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  libkdumpfile-devel
BuildRequires:  libtool
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
drgn (pronounced “dragon”) is a debugger with an emphasis on
programmability. drgn exposes the types and variables in a program
for easy, expressive scripting in Python.

%prep
%setup -q -n drgn-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/drgn
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pyunittest_arch discover -v

%post
%python_install_alternative drgn

%postun
%python_uninstall_alternative drgn

%files %{python_files}
%doc README.rst
%license COPYING
%python_alternative %{_bindir}/drgn
%{python_sitearch}/drgn
%{python_sitearch}/drgn-%{version}*-info
%{python_sitearch}/_drgn*.pyi
%{python_sitearch}/_drgn*.so
%{python_sitearch}/_drgn_util

%changelog
* Thu Apr 17 2025 Petr Tesařík <ptesarik@suse.com>
- Update to drgn-0.0.31:
  * New command line options and APIs for controlling how debugging
    information is found
  * Improved debuginfod integration
  * Stack tracing through unknown kernel modules with ORC
  * New helpers
  * Bug fixes
- Drop upstreamed patches:
  * libdrgn-kdump-prepare-for-incompatible-changes-in-li.patch
  * libdrgn-kdump-simplify-getting-the-PRSTATUS-attribut.patch
* Thu Mar  6 2025 Michal Koutný <mkoutny@suse.com>
- RPM: move source to obscpio maintained with _service
- RPM: use modern (>=15.4) python macros
* Mon Dec 30 2024 Petr Tesařík <ptesarik@suse.com>
- Update to drgn-0.0.30:
  * Linux 6.13 support
  * Support for symbols without debuginfo
  * Use Python 3.13 enhanced REPL when available
  * Add a 'stat' subcommand to contrib/cgroup.py
  * Many bug fixes
- API compatibility with libkdumpfile-0.5.5:
  * libdrgn-kdump-prepare-for-incompatible-changes-in-li.patch
  * libdrgn-kdump-simplify-getting-the-PRSTATUS-attribut.patch
* Wed Oct  9 2024 Petr Tesařík <ptesarik@suse.com>
- Update to drgn-0.0.29:
  * Fix call_function(), write_memory(), and write_object() for
    kernels with CONFIG_MODVERSIONS=y
- Fix a few rpmlint warnings.
* Wed Oct  9 2024 Petr Tesařík <ptesarik@suse.com>
- Update to drgn-0.0.28:
  * Linux 6.11 and 6.12 support
  * Helpers for modifying the running kernel
  * 32-bit Arm address translation
  * AArch64 52-bit virtual addresses with 4k or 16k pages
* Thu Sep 26 2024 Michal Koutný <mkoutny@suse.com>
- Update RPM's Source: to match tarball proper
* Tue Jul  2 2024 Petr Tesařík <petr@tesarici.cz>
- Update to drgn-0.0.27:
  * Linux 6.9 and 6.10 support
  * New helpers for interpreting memory
  * New scripts in contrib
* Tue Mar 12 2024 Petr Tesařík <petr@tesarici.cz>
- Update to drgn-0.0.26:
  * Linux 6.8 Support
  * Python 3.13 Support
  * new tool: fsrefs.py
  * new Linux helpers: print_dmesg(), idr_for_each_entry(),
    stack_depot_fetch(), priority-sorted lists
  * support split DWARF package (.dwp) files
* Mon Dec  4 2023 Michal Koutný <mkoutny@suse.com>
- Cleanup .gitignore'd files from tarball
* Sat Dec  2 2023 Petr Tesařík <petr@tesarici.cz>
- Update to drgn-0.0.25:
  * omitting the prog argument
  * running without root privileges
  * maple tree helpers
  * VMA helpers
  * wait queue helpers
  * ppc64 radix MMU support
* Fri Sep  8 2023 Petr Tesařík <petr@tesarici.cz>
- Update to drgn-0.0.24:
  * Linked list length helper
  * Networking helpers
  * C++ lookups
  * Split DWARF
  * Performance improvements
* Thu Jun 29 2023 Petr Tesařík <petr@tesarici.cz>
- Update to drgn-0.0.23:
  * Support Linux 6.3 and 6.4
  * Full s390x support
  * Extend idr helpers for pre-4.11 Linux
  * Support GNU-style compressed .zdebug_* sections
  * New scripts in contrib
* Sat Jan  7 2023 Petr Tesařík <ptesarik@suse.com>
- Update to drgn-0.0.22:
  * License changed to LGPLv2.1+.
  * Linux kernel support was tested up to Linux 6.2-rc2.
  * Oldest kernel version officially supported is now 4.9.
  * The StackFrame.locals() method was added.
  * The StackFrame.sp attribute was added.
  * Helpers for XArrays were added.
  * The drgn.helpers.linux.slab.get_slab_aliases() helper was added.
  * The drgn.helpers.linux.slab.slab_object_info() helper was added.
  * The drgn.helpers.common.memory.identify_address() helper now
    provide the offset from the beginning of the slab object and
    whether it is allocated or free.
  * The drgn.helpers.common.stack.print_annotated_stack() helper was
    added.
  * Support for Linux kernel modules and stack unwinding on s390x.
  * Partial support for looking up types with C++ template
    arguments.
  * Parsing debug info for C++ template parameter packs.
* Fri Oct 14 2022 Petr Tesařík <ptesarik@suse.com>
- Update to drgn-0.0.21:
  * Linux kernel support up to Linux 6.0.
  * Helpers for lockless linked lists in the Linux kernel.
  * A helper to find the slab cache that a virtual address came.
  * A drgn.helpers.common package for helpers that can be used with
    any program (which may have program-specific additional
    behavior).
  * A helper to identify an arbitrary address (e.g., as a symbol or
    slab object).
  * PageFoo() helpers to check various struct page flags.
  * Helpers for working with compound pages.
  * A helper to get the CPU that a task last ran on.
  * Automatic pretty-printing in IPython/Jupyter.
  * drgn.StackTrace.prog was added as a way to get the program that a stack trace came from.
  * Bug fixes, documentation, minor API changes.
* Sun Aug 14 2022 Petr Tesařík <ptesarik@suse.com>
- Initial packaging for openSUSE.
